:tocdepth: 2

========
EC2 API
========

Provides a standalone EC2 API service. 

Amazon EC2 API Reference can be found `here 
<http://docs.aws.amazon.com/AWSEC2/latest/APIReference/Welcome.html>`_.

.. include:: supported_features.inc

